#
# spec file for package ghc-haskell-src-exts
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name haskell-src-exts
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.21.0
Release:        lp151.1.2
Summary:        Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  happy
%if %{with tests}
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-smallcheck-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-smallcheck-devel
%endif

%description
Haskell-Source with Extensions (HSE, haskell-src-exts) is a standalone parser
for Haskell. In addition to standard Haskell, all extensions implemented in GHC
are supported.

Apart from these standard extensions, it also handles regular patterns as per
the HaRP extension as well as HSX-style embedded XML syntax.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README.md

%changelog
* Sat Dec  8 2018 psimons@suse.com
- Update haskell-src-exts to version 1.21.0.
  1.20.3 --> 1.21.0
  =================
  * DerivingVia (#420)
  * TypeInType  (#414)
  * Parse TH-quoted list constructor (#415)
* Wed Oct 10 2018 psimons@suse.com
- Update haskell-src-exts to version 1.20.3.
  1.20.2 --> 1.20.3
  =================
  * GHC 8.6.1 compatability (MonadFail)
  * Remove cpphs dependency
* Fri Aug 17 2018 psimons@suse.com
- Update Cabal build information to support GHC 8.6.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update haskell-src-exts to version 1.20.2.
  * Add fixity of (&)
  * GHC 8.4.1 compatability
  * Fix two test failures
  * GHC 8.2 updates
  * Add some missing Generics instances (#380)
  * Support Template Haskell pattern splices (#352)
  * Fix overloaded labels starting with _ (#362)
  * Relax MultiParamTypeClass check (#333)
  * DeriveAnyClass (#337)
  * Deriving Strategies (#387)
  * OVERLAPS/OVERLAPPING/OVERLAPPABLE pragmas
  * Unboxed Sums
  * Expression holes in infix expressions
  * Support multiple pattern synonyms per pattern synonym signature
  * COMPLETE pragmas
  * Fix #309, remove unnecessary semi-colon from pretty printer
  * Refine ExplicitNamespaces to properly export type operators
  * Revert making fields of `SrcLoc` strict. (#340)
  * Add JavaScriptFFI to known extensions (#335)
  * Remove space when pretty printing `SrcLoc`. (#307)
  * Don't reverse arguments in a context. (#328)
  * Add support for EmptyCase extension (#255)
* Fri Apr 27 2018 guillaume.gardet@opensuse.org
- Add _constraints to avoid OOM errors on AArch64
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.18.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.17.1 revision 1 with cabal2obs.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.17.1
  * Fix bug in parsing view patterns (#284)
  * Replaced VarA with AppA in Asst (#168).
  * Promoted list/tuple members changed from Promoted to Type (#162).
  * Update PatBind, Match, and Alt from containing Binds to Maybe Binds to
  distinguish between empty where clauses and where clauses with no
  binds (#244).
  * Add RoleAnnotDecl and Role to support Role annotations (#215).
  * Move NameSpace field from EVar/IVar to EAbs/IAbs.
  * Add standalone parsers for ImportDecl.
  * Fix pretty-printer bugs for HaRP (#160).
  * Insert parentheses when pretty-printing non-atomic bang types (#169).
  * Un-reverse confusion of left and right arrow (#175).
  * Prettyprint option pragmas like 1.15 (#172).
  * Conditionally insert lines when pretty-printing declarations (#171).
  * Distinguish deriving (Show) from deriving Show (#189).
  * Allow parsing of unicode subscript and superscript functions (#173).
  * Pretty print unboxed tuples with spaces (#193).
  * Improve performance when parsing long extension lists (#200).
  * Properly pretty print constructor and class operators (#204).
  * Read Haskell source files as UTF-8 (#223).
  * Fix ExplicitNamespaces parsing (#216).
  * PolyKinds implies KindSignatures (#220).
  * Preserve location information for infix binds (#205).
  * Preserve positional information in checkPattern (#231).
  * Maintain correct line numbers when parsing multiline GHC_OPTIONS (#218).
  * Correctly parse "*" with TypeOperators (#81).
  * Export the "pretty" method (#222).
  * Add javascript calling convention for foreign imports (#236).
  * Add non-greedy parsers for module heads (#191).
  * Add a flag to disable arity checking when parsing (#260).
  * Parse "-" in type signatures (#206).
  * Add support for type wildcards and expression holes (#252).
  * Add support for Pattern Synonyms (#197).
  * Bump the happy lower bound (#250).
  * Make test suite pass on GHC 7.12 (#224).
  * Support linking Haddock comments to AST nodes (#213).
  * Parse multiline LANGUAGE pragmas (#217).
  * Parse trailing where (#25).
  * Parse modules starting with pragmas and indented
  "module" keyword (#122).
  * Use pretty-show to get human readable test outputs.
  * Respect fixity declarations inside where/let/class in
  `applyFixities` (#212).
  * Correctly parse the combination of view patterns and bang patterns. (#276)
* Wed Apr 29 2015 mimi.vx@gmail.com
- add _constraints file for ppc64le
* Sat Nov 22 2014 mimi.vx@gmail.com
- add group to devel section
* Fri Nov 21 2014 mimi.vx@gmail.com
- initial commit
